Welcome to drf-microservice documentation!
==========================================

.. image:: https://api.travis-ci.org/alainivars/drf-microservice.svg?branch=master
    :target: http://travis-ci.org/alainivars/drf-microservice
    :alt: Build status

.. image:: https://coveralls.io/repos/github/alainivars/drf-microservice/badge.svg?branch=master
    :target: https://coveralls.io/github/alainivars/drf-microservice?branch=master
    :alt: Test coverage status

.. image:: https://requires.io/github/alainivars/drf-microservice/requirements.svg?branch=master
    :target: https://requires.io/github/alainivars/drf-microservice/requirements/?branch=master
    :alt: Requirements Status

.. image:: https://img.shields.io/pypi/dm/drf-microservice.svg
   :target: https://pypi.python.org/pypi/drf-microservice/
   :alt: pypi download

.. image:: https://img.shields.io/pypi/pyversions/drf-microservice.svg
   :target: https://pypi.python.org/pypi/drf-microservice/
   :alt: python supported

.. image:: https://img.shields.io/pypi/l/drf-microservice.svg
   :target: https://pypi.python.org/pypi/drf-microservice/
   :alt: licence

.. image:: https://img.shields.io/pypi/v/drf-microservice.svg
   :target: https://pypi.python.org/pypi/drf-microservice
   :alt: PyPi version

.. image:: https://api.codeclimate.com/v1/badges/7e1409b460b27562eb8b/maintainability
   :target: https://codeclimate.com/github/alainivars/drf-microservice/maintainability
   :alt: Maintainability

.. image:: https://readthedocs.org/projects/drf-microservice/badge/?version=latest
   :target: https://readthedocs.org/projects/drf-microservice/?badge=latest
   :alt: Documentation status

.. image:: https://pypip.in/wheel/drf-microservice/badge.svg
   :target: https://pypi.python.org/pypi/drf-microservice/
   :alt: PyPi wheel

About Drf-microservice
======================
drf-microservice is a ready-to-use API skeleton:
    - `Cookiescutter-drf-microservice`_ generated it,
And you:
    - add your unittest and endpoints,
And it will help you to:
    - generate the documentation with drf-yasg,
    - test it with Tox,
    - package it Docker,
    - deploy it (TODO with) Terraform or Ansible

It sounds simple and it is. Take a look at `Drf-microservice`_ it's now generated by `Cookiescutter-drf-microservice`_.

Something disturb you in the code? Don't hesitate to open a an issue and contribute.

docker-compose
--------------
# create image(s) described in the docker-compose.yml:
    docker-compose build
# Builds, (re)creates, starts, and attaches to containers for a service:
    docker-compose up -d
# Stops, all the containers for a service:
    docker-compose down

urls
----
    xx.xx.xx.xx:8000
    xx.xx.xx.xx:8000/admin/
    xx.xx.xx.xx:8000/swagger/openapi/


`Releases notes`_

Bugs and evolution policies
===========================
When you will find a bug or propose an evolution create a ticket on:

- `Issue Cookiescutter-drf-microservice`_ if it's about the generation process
- `Issue Drf-microservice`_ if it's about a functionality in the generated drf process

Online documentation is here on `readthedoc`_
Online source code available on `Github`_

.. _`Cookiescutter-drf-microservice`: https://github.com/alainivars/cookiecutter-drf-microservice
.. _`Drf-microservice`: https://github.com/alainivars/drf-microservice
.. _`Issue Cookiescutter-drf-microservice`: https://github.com/alainivars/cookiecutter-drf-microservice/issues
.. _`Issue Drf-microservice`: https://github.com/alainivars/drf-microservice/issues
.. _`Readthedoc`: https://drf-microservice.readthedocs.io/en/latest/
.. _`Github`: https://github.com/alainivars/drf-microservice
.. _`Releases notes`: https://github.com/alainivars/drf-microservice/blob/master/docs/releases_notes.rst
